@@ -68,7 +68,7 @@ signal.signal(signal.SIGINT, sigint_handler)
 
 # Constants
 
-_VERSION_ = '3.6'
+_VERSION_ = '3.7.1'
 
 COLORMAP = {k: '\x1b[%sm' % v for k, v in {
     'a': '30', 'b': '31', 'c': '32', 'd': '33',
@@ -82,8 +82,7 @@ COLORMAP = {k: '\x1b[%sm' % v for k, v in {
     'x': '0', 'X': '1', 'y': '7', 'Y': '7;1',
 }.items()}
 
-# Disguise as Firefox on Ubuntu
-USER_AGENT = ('Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:60.0) Gecko/20100101 Firefox/60.0')
+USER_AGENT = ('googler/' + _VERSION_)
 ua = True  # User Agent is enabled by default
 
 text_browsers = ['elinks', 'links', 'lynx', 'w3m', 'www-browser']
@@ -2082,24 +2081,47 @@ class GooglerCmd(object):
                 elif cmd.startswith('c ') and cmd[2:].isdigit():
                     try:
                         # try copying the url to clipboard using native utilities
+                        copier_params = []
+                        copier_mode = 'stdin'
                         if sys.platform.startswith(('linux', 'freebsd', 'openbsd')):
-                            if shutil.which('xsel') is None:
-                                raise FileNotFoundError
-                            copier_params = ['xsel', '-b', '-i']
+                            if shutil.which('xsel') is not None:
+                                copier_params = ['xsel', '-b', '-i']
+                            elif shutil.which('xclip') is not None:
+                                copier_params = ['xclip', '-selection', 'clipboard']
+                            elif shutil.which('termux-clipboard-set') is not None:
+                                copier_params = ['termux-clipboard-set']
                         elif sys.platform == 'darwin':
                             copier_params = ['pbcopy']
                         elif sys.platform == 'win32':
                             copier_params = ['clip']
-                        else:
-                            copier_params = []
+
+                        # If native clipboard utilities are absent, try to use terminal
+                        # multiplexers, tmux/GNU screen, as fallback.
+                        if not copier_params:
+                            if os.getenv('TMUX_PANE'):  # check for tmux
+                                # Try to use tmux buffer as fallback. Use case suggested by #230.
+                                copier_params = ['tmux', 'set-buffer']
+                                copier_mode = 'cmdline_arg'
+                            elif os.getenv('STY'):  # check for GNU screen
+                                # Try to use GNU screen's exchange-file as fallback.
+                                copier_params = ['screen', '-X', 'readbuf']
+                                copier_mode = 'ext_file'
 
                         if not copier_params:
-                            printerr('operating system not identified')
+                            printerr('failed to locate suitable clipboard utility')
                         else:
-                            Popen(copier_params, stdin=PIPE, stdout=DEVNULL,
-                                  stderr=DEVNULL).communicate(self._urltable[cmd[2:]].encode('utf-8'))
-                    except FileNotFoundError:
-                        printerr('xsel missing')
+                            content = self._urltable[cmd[2:]].encode('utf-8')
+                            if copier_mode == 'stdin':
+                                Popen(copier_params, stdin=PIPE,
+                                      stdout=DEVNULL, stderr=DEVNULL).communicate(content)
+                            elif copier_mode == 'cmdline_arg':
+                                Popen(copier_params + [content], stdin=DEVNULL,
+                                      stdout=DEVNULL, stderr=DEVNULL).communicate()
+                            else:
+                                with open('/tmp/screen-exchange', 'wb') as f:
+                                    f.write(content)
+                                Popen(copier_params, stdin=DEVNULL,
+                                      stdout=DEVNULL, stderr=DEVNULL).communicate()
                     except Exception:
                         raise NoKeywordsException
                 else:
@@ -2363,7 +2385,7 @@ def parse_proxy_spec(proxyspec):
         host_port = proxyspec[pos+1:].rstrip('/')
     else:
         user_passwd = None
-        host_port = proxyspec
+        host_port = proxyspec.rstrip('/')
 
     if ':' not in host_port:
         # Use port 1080 as default, following curl.
@@ -2381,6 +2403,7 @@ def parse_proxy_spec(proxyspec):
 # instance, they won't if the specified prefix ends in a punctuation
 # mark.)
 def completer_fetch_completions(prefix):
+    import html
     import json
     import re
     import urllib.request
@@ -2407,7 +2430,7 @@ def completer_fetch_completions(prefix):
     # Note the each result entry need not have two members; e.g., for
     # 'gi', there is an entry ['gi<b>f</b>', 0, [131]].
     HTML_TAG = re.compile(r'<[^>]+>')
-    return [HTML_TAG.sub('', entry[0]) for entry in respobj[1]]
+    return [html.unescape(HTML_TAG.sub('', entry[0])) for entry in respobj[1]]
 
 
 def completer_run(prefix):
